@@ -1,7 +1,6 @@
 import os.path
 import subprocess
 import importlib.util
-import sys
 
 
 def _get_py_hook_type(hook_type: str) -> None | str:
@@ -18,7 +17,7 @@ def _execute_shell_hook(hook_type: str):
 
 
 def _execute_python_hook(hook_type: str):
-    spec = importlib.util.spec_from_file_location("post-commit", "./.barb/post-commit.py")
+    spec = importlib.util.spec_from_file_location(hook_type, f"./.barb/{hook_type}.py")
     foo = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(foo)
 
